# git-task

[![Build Status](https://travis-ci.com/bessbd/git-task.svg?branch=master)](https://travis-ci.com/bessbd/git-task)

## Dependencies
* [Python >=3.7](https://www.python.org/downloads/release/python-370/)

## Installation

```
pip install gittask && gittask install_git_alias
```
